@@ -1,11 +1,10 @@
 """
 TODO:
   * Gør elev og lærer id til id men hvor at elev id har et S foran (Eks: S123456789) og lærer har et T foran (Eks: T12345678)
-  * Fjern retry fra enkelte funktioner og gør det til en general ting
 """
 
 from .imports import *
-from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer
+from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer, _studieretning
 
 class sdk:
     def __init__(self, brugernavn, adgangskode, skoleId, base64Cookie=None):
@@ -35,8 +34,8 @@ class sdk:
     def lektier(self):
         return _lektier.lektier(self)
 
-    def skema(self, retry=False, uge=None, år=None, elevId=None):
-        return _skema.skema(self, retry=retry, uge=uge, år=år, elevId=elevId)
+    def skema(self, uge=None, år=None, id=None):
+        return _skema.skema(self, uge=uge, år=år, id=id)
 
     def modul(self, absid):
         return _modul.modul(self, absid)
@@ -80,4 +79,7 @@ class sdk:
         return _ledigeLokaler.ledigeLokaler(self)
 
     def karakterer(self):
-        return _karakterer.karakterer(self)
\ No newline at end of file
+        return _karakterer.karakterer(self)
+
+    def studieretningspræsentation(self):
+        return _studieretning.studieretningspræsentation(self)
\ No newline at end of file
